@@ -18,6 +18,7 @@ class TimeType:
     TRAINING: str = "TRAINING"
     RUN: str = "RUN"
     SAVING_MODEL: str = "SAVING_MODEL"
+    EVALUATION: str = "EVALUATION"
 
 
 MAX_LENGTH_TIME_TYPES = max([len(x) for x in TimeType().__dict__.values()])
@@ -81,7 +82,8 @@ def get_max_memory_usage():
 
 
 def init_cuda():
-    torch.cuda.init()
+    if torch.cuda.is_available():
+        torch.cuda.init()
 
 
 def reset_cuda_memory_monitoring():
